==> layout-7.1.13-sources.jar: com/itextpdf/layout/font/RangeBuilder.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2020 iText Group NV
    Authors: iText Software.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License version 3
    as published by the Free Software Foundation with the addition of the
    following permission added to Section 15 as permitted in Section 7(a):
    FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
    ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
    OF THIRD PARTY RIGHTS

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU Affero General Public License for more details.
    You should have received a copy of the GNU Affero General Public License
    along with this program; if not, see http://www.gnu.org/licenses or write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA, 02110-1301 USA, or download the license from the following URL:
    http://itextpdf.com/terms-of-use/

    The interactive user interfaces in modified source and object code versions
    of this program must display Appropriate Legal Notices, as required under
    Section 5 of the GNU Affero General Public License.

    In accordance with Section 7(b) of the GNU Affero General Public License,
    a covered work must retain the producer line in every PDF that is created
    or manipulated using iText.

    You can be released from the requirements of the license by purchasing
    a commercial license. Buying such a license is mandatory as soon as you
    develop commercial activities involving the iText software without
    disclosing the source code of your own applications.
    These activities include: offering paid services to customers as an ASP,
    serving PDFs on the fly in a web application, shipping iText with a closed
    source product.

    For more information, please contact iText Software Corp. at this
    address: sales@itextpdf.com
 */
package com.itextpdf.layout.font;

import java.util.ArrayList;
import java.util.List;

/**
 * Builder of {@link Range}.
 */
public class RangeBuilder {

    private static final Range fullRangeSingleton = new Range.FullRange();

    private List<Range.SubRange> ranges = new ArrayList<>();

    /**
     * Default Range instance.
     *
     * @return Range that contains any integer
     */
    static Range getFullRange() {
        return fullRangeSingleton;
    }


    /**
     * Default constructor with empty range.
     */
    public RangeBuilder() {
    }

    /**
     * Constructor with a single range.
     *
     * @param low  low boundary of the range
     * @param high high boundary of the range
     */
    public RangeBuilder(int low, int high) {
        this.addRange(low, high);
    }

    /**
     * Constructor with a single number.
     *
     * @param n a single number
     */
    public RangeBuilder(int n) {
        this(n, n);
    }

    /**
     * Constructor with a single range.
     *
     * @param low  low boundary of the range
     * @param high high boundary of the range
     */
    public RangeBuilder(char low, char high) {
        this((int) low, (int) high);
    }

    /**
     * Constructor with a single char.
     *
     * @param ch a single char
     */
    public RangeBuilder(char ch) {
        this((int) ch);
    }

    /**
     * Add one more range.
     *
     * @param low  low boundary of the range
     * @param high high boundary of the range
     * @return this RangeBuilder
     */
    public RangeBuilder addRange(int low, int high) {
        if (high < low) {
            throw new IllegalArgumentException("'from' shall be less than 'to'");
        }
        ranges.add(new Range.SubRange(low, high));
        return this;
    }

    /**
     * Add one more range.
     *
     * @param low  low boundary of the range
     * @param high high boundary of the range
     * @return this RangeBuilder
     */
    public RangeBuilder addRange(char low, char high) {
        return addRange((int) low, (int) high);
    }

    /**
     * Add range with a single number.
     *
     * @param n a single number
     * @return this RangeBuilder
     */
    public RangeBuilder addRange(int n) {
        return addRange(n, n);
    }

    /**
     * Add range with a single char.
     *
     * @param ch a single char
     * @return this RangeBuilder
     */
    public RangeBuilder addRange(char ch) {
        return addRange((int) ch);
    }


    public Range create() {
        return new Range(ranges);
    }
}

==> layout-7.1.16-sources.jar: com/itextpdf/layout/font/RangeBuilder.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2021 iText Group NV
    Authors: iText Software.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License version 3
    as published by the Free Software Foundation with the addition of the
    following permission added to Section 15 as permitted in Section 7(a):
    FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
    ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
    OF THIRD PARTY RIGHTS

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU Affero General Public License for more details.
    You should have received a copy of the GNU Affero General Public License
    along with this program; if not, see http://www.gnu.org/licenses or write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA, 02110-1301 USA, or download the license from the following URL:
    http://itextpdf.com/terms-of-use/

    The interactive user interfaces in modified source and object code versions
    of this program must display Appropriate Legal Notices, as required under
    Section 5 of the GNU Affero General Public License.

    In accordance with Section 7(b) of the GNU Affero General Public License,
    a covered work must retain the producer line in every PDF that is created
    or manipulated using iText.

    You can be released from the requirements of the license by purchasing
    a commercial license. Buying such a license is mandatory as soon as you
    develop commercial activities involving the iText software without
    disclosing the source code of your own applications.
    These activities include: offering paid services to customers as an ASP,
    serving PDFs on the fly in a web application, shipping iText with a closed
    source product.

    For more information, please contact iText Software Corp. at this
    address: sales@itextpdf.com
 */
package com.itextpdf.layout.font;

import java.util.ArrayList;
import java.util.List;

/**
 * Builder of {@link Range}.
 */
public class RangeBuilder {

    private static final Range fullRangeSingleton = new Range.FullRange();

    private List<Range.SubRange> ranges = new ArrayList<>();

    /**
     * Default Range instance.
     *
     * @return Range that contains any integer
     */
    static Range getFullRange() {
        return fullRangeSingleton;
    }


    /**
     * Default constructor with empty range.
     */
    public RangeBuilder() {
    }

    /**
     * Constructor with a single range.
     *
     * @param low  low boundary of the range
     * @param high high boundary of the range
     */
    public RangeBuilder(int low, int high) {
        this.addRange(low, high);
    }

    /**
     * Constructor with a single number.
     *
     * @param n a single number
     */
    public RangeBuilder(int n) {
        this(n, n);
    }

    /**
     * Constructor with a single range.
     *
     * @param low  low boundary of the range
     * @param high high boundary of the range
     */
    public RangeBuilder(char low, char high) {
        this((int) low, (int) high);
    }

    /**
     * Constructor with a single char.
     *
     * @param ch a single char
     */
    public RangeBuilder(char ch) {
        this((int) ch);
    }

    /**
     * Add one more range.
     *
     * @param low  low boundary of the range
     * @param high high boundary of the range
     * @return this RangeBuilder
     */
    public RangeBuilder addRange(int low, int high) {
        if (high < low) {
            throw new IllegalArgumentException("'from' shall be less than 'to'");
        }
        ranges.add(new Range.SubRange(low, high));
        return this;
    }

    /**
     * Add one more range.
     *
     * @param low  low boundary of the range
     * @param high high boundary of the range
     * @return this RangeBuilder
     */
    public RangeBuilder addRange(char low, char high) {
        return addRange((int) low, (int) high);
    }

    /**
     * Add range with a single number.
     *
     * @param n a single number
     * @return this RangeBuilder
     */
    public RangeBuilder addRange(int n) {
        return addRange(n, n);
    }

    /**
     * Add range with a single char.
     *
     * @param ch a single char
     * @return this RangeBuilder
     */
    public RangeBuilder addRange(char ch) {
        return addRange((int) ch);
    }


    /**
     * Creates a {@link Range} instance based on added ranges.
     *
     * @return the {@link Range} instance based on added ranges
     */
    public Range create() {
        return new Range(ranges);
    }
}
